==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractPaymentVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;

import com.ejianc.business.contractpub.util.ConvertField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 安拆合同付款阶段实体
 * 
 * @author generator
 * 
 */
public class ContractPaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ConvertField(targetField = "paymentNodeName")
    private String paymentName; // 付款阶段名称
    @ConvertField(targetField = "totalActualPayRecTax")
    private BigDecimal paymentScale; // 付款阶段比例(%)
    @ConvertField(targetField = "memo")
    private String mark; // 备注
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键

    @ConvertField(targetField = "sourceId,id")
    private Long id;

    @ConvertField
    private Integer dr;

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }
    

    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }
    public BigDecimal getPaymentScale() {
        return paymentScale;
    }

    public void setPaymentScale(BigDecimal paymentScale) {
        this.paymentScale = paymentScale;
    }
    public String getMark() {
        return mark;
    }

    public void setMark(String mark) {
        this.mark = mark;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20230215.092206-323-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractPaymentVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;

import com.ejianc.business.contractpub.util.ConvertField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 安拆合同付款阶段实体
 * 
 * @author generator
 * 
 */
public class ContractPaymentVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    @ConvertField(targetField = "paymentNodeName")
    private String paymentName; // 付款阶段名称
    @ConvertField(targetField = "totalActualPayRecTax")
    private BigDecimal paymentScale; // 付款阶段比例(%)
    @ConvertField(targetField = "memo")
    private String mark; // 备注
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    private String paymentScaleStr;

    @ConvertField(targetField = "sourceId,id")
    private Long id;

    @ConvertField
    private Integer dr;

    @Override
    public Long getId() {
        return id;
    }

    @Override
    public void setId(Long id) {
        this.id = id;
    }

    @Override
    public Integer getDr() {
        return dr;
    }

    @Override
    public void setDr(Integer dr) {
        this.dr = dr;
    }
    

    public String getPaymentName() {
        return paymentName;
    }

    public void setPaymentName(String paymentName) {
        this.paymentName = paymentName;
    }
    public BigDecimal getPaymentScale() {
        return paymentScale;
    }

    public void setPaymentScale(BigDecimal paymentScale) {
        this.paymentScale = paymentScale;
    }
    public String getMark() {
        return mark;
    }

    public void setMark(String mark) {
        this.mark = mark;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }


    public String getPaymentScaleStr() {
        return paymentScaleStr;
    }

    public void setPaymentScaleStr(String paymentScaleStr) {
        this.paymentScaleStr = paymentScaleStr;
    }
}
